__title__ = 'ultimux'
__package_name__ = 'ultimux'
__version__ = '0.2.0'
__description__ = "A multiprocessing module based on starting tmux sessions"
__email__ = "george@cerebralab.com"
__author__ = 'George Hosu'
__github__ = 'https://github.com/George3d6/ultimux'
__pypi__ = 'https://pypi.org/project/ultimux'
__license__ = 'MIT'
